perl -e '
require "/home/app/cafeterra/cgi/EN/translate.pm";
my %s = %cafetrans::translation;
%cafetrans::translation = undef;
require "/home/app/cafeterra/cgi/FR/translate.pm.old";
my %f = %cafetrans::translation;
%cafetrans::translation = undef;
require "/home/app/cafeterra/cgi/EN/translate.pm.old";
my %e = %cafetrans::translation;
%cafetrans::translation = undef;

my %S;
foreach my $k (keys %s) {
	$S{uc $k} = $s{$k};
}

foreach $w (keys %e) {
	if (! $S{uc $w}) {
		print "EN ", sprintf("\"%-25s => \"%s\",\n", $w . "\"", $e{$w});
		print "FR ", sprintf("\"%-25s => \"%s\",\n", $w . "\"",	$f{$w});
	}
 }' | sort -u
